==> haskell-terminal-size-0.3.2.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-terminal-size.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 terminal-size
version:              0.3.2.1
visibility:           public
id:                   terminal-size-0.3.2.1-Lp3EPz6AmPvE7uvVvixMVf
key:                  terminal-size-0.3.2.1-Lp3EPz6AmPvE7uvVvixMVf
license:              BSD-3-Clause
maintainer:           matvey.aksenov@gmail.com
author:               Andreas Hammar, Matvey Aksenov
synopsis:             Get terminal window height and width
description:
    Get terminal window height and width without ncurses dependency.

category:             System
abi:                  91e37ccb0875b695fb611bf4674277bd
exposed:              True
exposed-modules:      System.Console.Terminal.Size
hidden-modules:
    System.Console.Terminal.Common System.Console.Terminal.Posix

import-dirs:          /usr/lib/ghc-8.8.3/site-local/terminal-size-0.3.2.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/terminal-size-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/terminal-size-0.3.2.1
hs-libraries:         HSterminal-size-0.3.2.1-Lp3EPz6AmPvE7uvVvixMVf
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-terminal-size/html/terminal-size.haddock

haddock-html:         /usr/share/doc/haskell-terminal-size/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-terminal-size-0.3.2.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-terminal-size.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 terminal-size
version:              0.3.2.1
visibility:           public
id:                   terminal-size-0.3.2.1-CDCO963D77gKCavfBZSlNE
key:                  terminal-size-0.3.2.1-CDCO963D77gKCavfBZSlNE
license:              BSD-3-Clause
maintainer:           matvey.aksenov@gmail.com
author:               Andreas Hammar, Matvey Aksenov
synopsis:             Get terminal window height and width
description:
    Get terminal window height and width without ncurses dependency.

category:             System
abi:                  94a951126a72d81823baa8384e546270
exposed:              True
exposed-modules:      System.Console.Terminal.Size
hidden-modules:
    System.Console.Terminal.Common System.Console.Terminal.Posix

import-dirs:          /usr/lib/ghc-8.10.1/site-local/terminal-size-0.3.2.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/terminal-size-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/terminal-size-0.3.2.1
hs-libraries:         HSterminal-size-0.3.2.1-CDCO963D77gKCavfBZSlNE
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-terminal-size/html/terminal-size.haddock

haddock-html:         /usr/share/doc/haskell-terminal-size/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
